.. Axelrod documentation master file, created by
   sphinx-quickstart on Sat Mar  7 07:05:57 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the documentation for the Axelrod Python library
===========================================================

.. toctree::
   :maxdepth: 3

   tutorials/index.rst
   reference/index.rst
   citing_the_library.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

